Refactor debug info generation
Get series with b4
b4 am [email protected]Versions newest first
- v1 Latest4 patches 0 repliesNew
Patches in v1 No applies recorded yet
| # | Subject and files | Size | Replies | Applied |
|---|---|---|---|---|
| 1/4 | package.bbclass: Breakout the strip from the populate_packagesmeta/ | +36 | 0 replies | |
| 2/4 | Revise stripping and splitting of debug informationmeta/ meta/ meta/ +1 more | +241 | 0 replies | |
| 3/4 | package.bbclass: Refactor split and strip functionmeta/ | +144 | 0 replies | |
| 4/4 | recipes: pre/post actionsmeta/ meta/ meta/ +12 more | +22 | 0 replies |
Reviews trailers per patch
No Reviewed-by, Acked-by or Tested-by trailers for v1 yet.
Cover letter [PATCH 0/4] Refactor debug info generation
The primary purpose of this patch is to refactor the way the -dbg packages and associated files are generated. In the original code it's being done in one operation with the splitting and stripping of the files within the populate_packages. The code was split from there, and then modified in two steps to get to the final version.
The first step implemented the new method where the split occurs and then the strip occurs. This makes it easier to tailor each of them as things change in the future.
The second path refactors this to eleminate multiple file walks and file identification processing. The behavior of the system is the same, only things are more efficient.
The fourth patch is simply a bug fix to some pre/post actions I found while diagnosing and debugging. This patch is separate from the rest of the refactoring and should be merged, even if the others are not.
FYI, I also did timing on this to see how it impacted system performance. The times below affect ONLY the do_package [and later] stages, on my specific host. (8 core with a 16/16 build configuration)
Original before these changes:
real 37m29.035s user 41m14.322s sys 31m0.006s
After the changes -- using "debian" style debuginfo, i.e. the same output as the original style:
real 36m48.160s user 42m17.636s sys 31m47.846s
After the changes -- using the new "fedora" style debug info:
real 38m48.793s user 44m9.822s sys 37m48.803s
The first two are nearly the same. Any deviation is likely due to the additional hardlink/symlink processing.
The fedora style introduces additional steps in the process that rewrite source code references and duplicate specific source code files into the -dbg directory for later (easier) debugging.
Pull URL: git://git.pokylinux.org/poky-contrib.git
Branch: mhatle/debuginfo
Browse: http://git.pokylinux.org/cgit.cgi/poky-contrib/log/?h=mhatle/debuginfo
Thanks,
Mark Hatle <[email protected]>
---
Mark Hatle (4):
package.bbclass: Breakout the strip from the populate_packages Revise stripping and splitting of debug information package.bbclass: Refactor split and strip function
recipes: pre/post actions
meta/classes/insane.bbclass | 4 +- meta/classes/package.bbclass | 325 +++++++++++++++++--- meta/conf/bitbake.conf | 7 +- meta/conf/local.conf.sample | 28 ++ meta/recipes-bsp/hostap/hostap-conf_1.0.bb | 4 +- meta/recipes-bsp/lrzsz/lrzsz_0.12.20.bb | 4 +- meta/recipes-bsp/orinoco/orinoco-conf_1.0.bb | 4 +- .../libnss-mdns/libnss-mdns_0.10.bb | 4 +- .../ppp-dialin/ppp-dialin_0.1.bb | 4 +- .../recipes-core/base-passwd/base-passwd_3.5.22.bb | 2 +- meta/recipes-core/dropbear/dropbear.inc | 4 +- .../sgml-common/sgml-common_0.6.3.bb | 4 +- meta/recipes-extended/bash/bash.inc | 2 +- meta/recipes-extended/bash/bash_3.2.48.bb | 2 +- meta/recipes-extended/sudo/sudo.inc | 2 +- .../ttf-fonts/liberation-fonts_1.04.bb | 2 +- .../ttf-fonts/liberation-fonts_1.06.bb | 2 +- .../ttf-fonts/ttf-bitstream-vera_1.10.bb | 2 +- .../update-modules/update-modules_1.0.bb | 2 +- 19 files changed, 340 insertions(+), 68 deletions(-)
Signature · 1 line
1.7.3.4